@@ -16,7 +16,7 @@ pt$addColumnDataGroups("TrainCategory")
 pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFFF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFFF00"))
 groups <- pt$findColumnDataGroups(variableNames="TrainCategory")
 groupCount <- lapply(groups, function(grp) {grp$style <- highlight})
 pt$renderPivot()
@@ -29,7 +29,7 @@ pt$addColumnDataGroups("TrainCategory")
 pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFFF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFFF00"))
 groups <- pt$findColumnDataGroups(variableValues=list("PowerType"=c("DMU", "HST")))
 groupCount <- lapply(groups, function(grp) {grp$style <- highlight})
 pt$renderPivot()
@@ -42,7 +42,7 @@ pt$addColumnDataGroups("TrainCategory")
 pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFFF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFFF00"))
 groups <- pt$findColumnDataGroups(variableNames="TrainCategory", totals="exclude")
 groupCount <- lapply(groups, function(grp) {grp$style <- highlight})
 pt$renderPivot()
@@ -55,7 +55,7 @@ pt$addColumnDataGroups("TrainCategory")
 pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFFF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFFF00"))
 groups <- pt$findColumnDataGroups(variableNames="TrainCategory", totals="only")
 groupCount <- lapply(groups, function(grp) {grp$style <- highlight})
 pt$renderPivot()
@@ -68,7 +68,7 @@ pt$addColumnDataGroups("TrainCategory")
 pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFFF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFFF00"))
 groups <- pt$findColumnDataGroups(
   variableValues=list("TrainCategory"="Ordinary Passenger"), 
   includeDescendantGroup=TRUE)
@@ -83,7 +83,7 @@ pt$addColumnDataGroups("TrainCategory")
 pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFFF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFFF00"))
 groups <- pt$findColumnDataGroups(
   variableValues=list("TrainCategory"="**"), 
   includeDescendantGroup=TRUE)
@@ -98,7 +98,7 @@ pt$addColumnDataGroups("TrainCategory")
 pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#00FFFF"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#00FFFF"))
 groups <- pt$findColumnDataGroups(matchMode="combinations",
                                   variableNames=c("TrainCategory", "PowerType"))
 groupCount <- lapply(groups, function(grp) {grp$style <- highlight})
@@ -112,7 +112,7 @@ pt$addColumnDataGroups("TrainCategory")
 pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#00FFFF"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#00FFFF"))
 groups <- pt$findColumnDataGroups(matchMode="combinations",
   variableValues=list("TrainCategory"="Express Passenger", "PowerType"=c("DMU", "HST")))
 groupCount <- lapply(groups, function(grp) {grp$style <- highlight})
@@ -126,7 +126,7 @@ pt$addColumnDataGroups("TrainCategory")
 pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFFF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFFF00"))
 groups <- pt$findColumnDataGroups(
   variableValues=list("TrainCategory"="Express Passenger", "PowerType"=c("DMU", "HST")))
 groupCount <- lapply(groups, function(grp) {grp$style <- highlight})
@@ -140,7 +140,7 @@ pt$addColumnDataGroups("TrainCategory")
 pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#00FFFF"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#00FFFF"))
 groups <- pt$findColumnDataGroups(matchMode="combinations", variableNames="PowerType",
   variableValues=list("TrainCategory"="Express Passenger"))
 groupCount <- lapply(groups, function(grp) {grp$style <- highlight})
@@ -154,7 +154,7 @@ pt$addColumnDataGroups("TrainCategory")
 pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#00FFFF"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#00FFFF"))
 groups <- pt$findColumnDataGroups(matchMode="combinations", 
   variableValues=list("TrainCategory"="Express Passenger", "PowerType"="**"))
 groupCount <- lapply(groups, function(grp) {grp$style <- highlight})
@@ -169,7 +169,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFCC66"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFCC66"))
 cells <- pt$getCells(specifyCellsAsList=TRUE, rowNumbers=c(1, 3))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -183,7 +183,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFCC66"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFCC66"))
 cells <- pt$getCells(specifyCellsAsList=TRUE, columnNumbers=2)
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -197,7 +197,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFCC66"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFCC66"))
 cells <- pt$getCells(specifyCellsAsList=TRUE, cellCoordinates=list(c(2, 3)))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 cat("The raw value of the cell is", cells[[1]]$rawValue, "and the formatted value is", cells[[1]]$formattedValue, ".")
@@ -212,7 +212,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFCC66"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFCC66"))
 cells <- pt$getCells(specifyCellsAsList=TRUE, cellCoordinates=list(c(2, 3), c(3, 4), c(5, 7)))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -226,7 +226,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FFCC66"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FFCC66"))
 cells <- pt$getCells(specifyCellsAsList=TRUE, rowNumbers=2, columnNumbers=4, cellCoordinates=list(c(5, 7)))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -240,7 +240,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#00FF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#00FF00"))
 cells <- pt$getCells(specifyCellsAsList=FALSE, rowNumbers=c(1, 3))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -254,7 +254,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#00FF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#00FF00"))
 cells <- pt$getCells(specifyCellsAsList=FALSE, columnNumbers=2)
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -268,7 +268,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#00FF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#00FF00"))
 cells <- pt$getCells(specifyCellsAsList=FALSE, rowNumbers=2, columnNumbers=3)
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 cat("The raw value of the cell is", cells[[1]]$rawValue, "and the formatted value is", cells[[1]]$formattedValue, ".")
@@ -283,7 +283,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#00FF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#00FF00"))
 cells <- pt$getCells(specifyCellsAsList=FALSE, rowNumbers=c(2, 3, 5), columnNumbers=c(3, 4, 7))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -297,7 +297,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#00FF00"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#00FF00"))
 cells <- pt$getCells(specifyCellsAsList=FALSE, rowNumbers=c(2, NA, 5), columnNumbers=c(NA, 4, 7))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -311,7 +311,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FF00FF"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FF00FF"))
 cells <- pt$findCells(variableNames="PowerType")
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -325,7 +325,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FF00FF"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FF00FF"))
 cells <- pt$findCells(variableValues=list("PowerType"=c("DMU", "HST")))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -339,7 +339,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FF00FF"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FF00FF"))
 cells <- pt$findCells(variableValues=list("PowerType"=c("DMU", "HST"), "TOC"="London Midland"))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -353,7 +353,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FF00FF"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FF00FF"))
 cells <- pt$findCells(variableNames="PowerType", totals="only")
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -367,7 +367,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FF00FF"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FF00FF"))
 cells <- pt$findCells(variableValues=list("PowerType"="**"))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -381,7 +381,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FF00FF"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FF00FF"))
 cells <- pt$findCells(variableValues=list("TrainCategory"="!*", "PowerType"="**"))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -395,7 +395,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-highlight <- PivotStyle$new(pt, "cellHighlight", list("background-color"="#FF00FF"))
+highlight <- pt$createInlineStyle(declarations=list("background-color"="#FF00FF"))
 cells <- pt$findCells(variableValues=list("TrainCategory"="**", "PowerType"="**", "TOC"="**"))
 lst <- lapply(cells, function(cell) {cell$style <- highlight})
 pt$renderPivot()
@@ -409,7 +409,7 @@ pt$addColumnDataGroups("PowerType")
 pt$addRowDataGroups("TOC")
 pt$defineCalculation(calculationName="TotalTrains", summariseExpression="n()")
 pt$evaluatePivot()
-redStyle <- PivotStyle$new(pt, "redStyle", list("background-color"="#FFC7CE", "color"="#9C0006"))
+redStyle <- pt$createInlineStyle(declarations=list("background-color"="#FFC7CE", "color"="#9C0006"))
 cells <- pt$findCells(minValue=30000, maxValue=50000, includeNull=FALSE, includeNA=FALSE)
 lst <- lapply(cells, function(cell) {cell$style <- redStyle})
 pt$renderPivot()
@@ -459,9 +459,10 @@ pt$defineCalculation(calculationName="AvgDelayMins", type="calculation",
 pt$evaluatePivot()
 
 # define three cell styles
-greenStyle <- PivotStyle$new(pt, "greenStyle", list("background-color"="#C6EFCE", "color"="#006100"))
-yellowStyle <- PivotStyle$new(pt, "yellowStyle", list("background-color"="#FFEB9C", "color"="#9C5700"))
-redStyle <- PivotStyle$new(pt, "redStyle", list("background-color"="#FFC7CE", "color"="#9C0006"))
+greenStyle <- pt$createInlineStyle(declarations=list("background-color"="#C6EFCE", "color"="#006100"))
+yellowStyle <- pt$createInlineStyle(declarations=list("background-color"="#FFEB9C", "color"="#9C5700"))
+redStyle <- pt$createInlineStyle(declarations=list("background-color"="#FFC7CE", "color"="#9C0006"))
+
 # apply the green style for an average arrival delay of between 0 and 2 minutes
 cells <- pt$findCells(minValue=0, maxValue=2, includeNull=FALSE, includeNA=FALSE)
 lst <- lapply(cells, function(cell) {cell$style <- greenStyle})
@@ -564,7 +565,7 @@ for(i in 1:length(cells)) {
   value <- cell$rawValue
   textClr <- scale3Colours(textClrGreen, textClrYellow, textClrRed, 0.5, 2, 4, value)
   backClr <- scale3Colours(backClrGreen, backClrYellow, backClrRed, 0.5, 2, 4, value)
-  cell$style <- PivotStyle$new(pt, "", list("background-color"=backClr, "color"=textClr))
+  cell$style <- pt$createInlineStyle(declarations=list("background-color"=backClr, "color"=textClr))
 }
 pt$renderPivot()
 
